

def convert_byte_to_mb(byte: int) -> float:
    return byte / (1024 * 1024)


def get_total_sec_from_msec(msec: int) -> int:
    return msec // 1000


def get_sec60_from_msec(msec: int) -> int:
    return get_total_sec_from_msec(msec) % 60


def get_min_from_msec(msec: int) -> int:
    return get_total_sec_from_msec(msec) // 60


import logging
import os
import unittest
from pathlib import Path

from pylizlib.config.pylizapp import PylizApp
from pylizlib.data.jsonUtils import JsonUtils
from dotenv import load_dotenv

from pylizlib.log.pylizLogger import PYLIZ_LIB_LOGGER_NAME, logger
from pylizlib.os import fileutils, pathutils


class TestFiles(unittest.TestCase):

    def setUp(self):
        pyliz_app = PylizApp("PylizTest", "0.0.1")
        logger.debug("setUp")

    def test_clean_json(self):
        json = "```json{'status': 'success', 'data': {'version': '0.0.1', 'execPath': '/usr/bin/eagle', 'prereleaseVersion': '0.0.1', 'buildVersion': '0.0.1', 'platform': 'linux'}}```"
        result = JsonUtils.clean_json_apici(json)
        print(result)

    def test_file_hash(self):
        load_dotenv()
        path = os.getenv("LOCAL_IMAGE_FOR_TEST")
        print(path)
        print(fileutils.gen_file_hash(path))

if __name__ == '__main__':
    unittest.main()


import unittest

from pylizlib.config.pylizapp import PylizApp


class TestScripts(unittest.TestCase):

    def setUp(self):
        self.dir = PylizApp(".pyliz")

    def test1(self):
        self.dir.create_ini("test.ini", [])
        self.dir.set_ini_value("sezione1", "chiave1", "value1")
        self.dir.set_ini_value("sezione1", "chiave1", False)


if __name__ == "__main__":
    unittest.main()


from dataclasses import dataclass

from pylizlib.log.pylizLogger import logger


@dataclass
class TaskProgress:
    task_id: str
    task_progress: int


@dataclass
class OperationProgress:
    operation_id: str
    operation_progress: float
    operation_tasks: list[TaskProgress]

    def set_task_progress(self, task_id: str, progress: int):
        for task in self.operation_tasks:
            if task.task_id == task_id:
                task.task_progress = progress
                return
        logger.warning("Task %s not found in operation %s", task_id, self.operation_id)

    def get_operation_progress(self):
        total_progress = sum(task.task_progress for task in self.operation_tasks)
        if self.operation_tasks:
            self.operation_progress = total_progress / len(self.operation_tasks)
        else:
            self.operation_progress = 0
        return self.operation_progress


class ProgressHandler:

    def __init__(self):
        self.operations: list[OperationProgress] = []

    def __get_operation_task(self, task_id: str):
        for operation in self.operations:
            for task in operation.operation_tasks:
                if task.task_id == task_id:
                    return task
        return None

    def add_operation(self, id: str, tasks_ids: list[str]):
        tasks = []
        for task_id in tasks_ids:
            tasks.append(TaskProgress(task_id=task_id, task_progress=0))
        self.operations.append(OperationProgress(
            operation_id=id,
            operation_progress=0,
            operation_tasks=tasks
        ))

    def set_task_progress(self, operation_id: str, task_id: str, progress: int):
        for operation in self.operations:
            if operation.operation_id == operation_id:
                operation.set_task_progress(task_id, progress)
                return

    def get_master_progress(self):
        total_progress = sum(operation.get_operation_progress() for operation in self.operations)
        if self.operations:
            return total_progress / len(self.operations)
        else:
            return 0

    def get_operation_progress(self, operation_id: str):
        for operation in self.operations:
            if operation.operation_id == operation_id:
                return operation.get_operation_progress()
        return 0




import os
from enum import Enum
from typing import List

from pylizlib.log.pylizLogger import logger

from pylizlib.os import pathutils
from pylizlib.config.cfgutils import Cfgini, CfgItem
from dataclasses import dataclass


class PylizDirFoldersTemplate(Enum):
    MODELS = "models"
    AI = "ai"
    TEMP = "temp"
    LOGS = "logs"
    RESULTS = "results"


@dataclass
class PylizDirFolder:
    key: str
    name: str
    path: str



class PylizApp:

    __folders: List[PylizDirFolder] = []
    __ini: Cfgini | None = None
    __ini_path: str | None = None
    __ini_initialized = False

    language_version: str | None = None


    def __init__(
            self,
            app_name: str,
            app_version: str | None = None,
            folder_name: str | None = None,
            author: str = "Unknown"
    ):
        """
        Constructor for PylizApp class.
        :param folder_name: Full name of the folder.
        """
        # Settaggio path
        app_folder_name = folder_name if folder_name is not None else app_name
        self.path: str = pathutils.get_app_home_dir(app_folder_name)
        # Cartella pyliz
        pathutils.check_path(self.path, True)
        pathutils.check_path_dir(self.path)
        # Settaggio variabili
        self.name = app_name
        self.version = app_version
        self.author = author

    def get_path(self):
        return self.path

    # FOLDERS --------------------------------------------

    def add_folder(self, key: str, folder_name: str):
        folder_path = os.path.join(self.path, folder_name)
        pathutils.create_path(folder_path)
        pathutils.check_path(folder_path, True)
        pathutils.check_path_dir(folder_path)
        self.__folders.append(PylizDirFolder(key, folder_name, folder_path))
        return folder_path

    def add_template_folder(self, template_key: PylizDirFoldersTemplate, name: str | None = None):
        folder_name = name if name is not None else template_key.value
        self.add_folder(template_key.value, folder_name)

    def add_all_template_folders(self):
        for template_key in PylizDirFoldersTemplate:
            self.add_template_folder(template_key)

    def add_folder_with_ini(self, key: str, folder_name: str, ini_section: str, ini_key: str):
        folder_path = self.add_folder(key, folder_name)
        self.set_ini_value(ini_section, ini_key, folder_path)

    def get_folder_path(self, key: str):
        for folder in self.__folders:
            if folder.key == key:
                return folder.path
        return None

    def get_folder_template_path(self, template_key: PylizDirFoldersTemplate, add_if_not_exist: bool = True):
        path = self.get_folder_path(template_key.value)
        if path is None and add_if_not_exist:
            return self.add_template_folder(template_key)
        else:
            return path

    def check_for_all_init(self):
        if not self.__ini.exists() or not self.__ini_initialized:
            raise Exception("PylizDirError: Configuration file not initialized or not found")

    # INI --------------------------------------------

    def create_ini(self, config_name: str, list_of_items: List[CfgItem] | None = None):
        self.__ini_path = os.path.join(self.path, config_name)
        self.__ini = Cfgini(self.__ini_path)
        if not self.__ini.exists():
            self.__ini.create(list_of_items)
        self.__ini_initialized = True

    def get_ini_value(self, section, key, is_bool=False):
        self.check_for_all_init()
        return self.__ini.read(section, key, is_bool)

    def set_ini_value(self, section, key, value):
        self.check_for_all_init()
        self.__ini.write(section, key, value)

    def get_ini_path(self):
        if self.__ini_initialized:
            return self.__ini_path
        else:
            return None

    def delete_ini(self):
        if self.__ini_initialized and os.path.exists(self.__ini_path):
            os.remove(self.__ini_path)
            self.__ini_initialized = False
            self.__ini = None
            self.__ini_path = None
        else:
            logger.warning("INI file not initialized. Nothing to delete.")

